    		~ Forms
    			~ Geometry
    			~ Shapes
    			~ Physiques

    		~ Vignette

    		~ Likeness

    		~ Pals
    			~ Buddies

    		~ Mech
    			~ Vehicles

    		~ Impersonation

    		~ Personas

    		~ Portrayals
    			~ Portraits

    		~ Reflections

    		~ Figures
    			~ Statues
    			~ Figurines
    			~ Idols
    			~ Dolls

    		~ Carnation
    			~ Rein-carnation

    		~ Biology

    		~ Lifeforms

    		~ Biota

    		~ Clones

    		~ Religion
    			~ Voodoo
    			~ Reincarnation

    		Stretch
    		Propsperity